@@ -1,4 +1,4 @@
-# Copyright 2018 QuantRocket - All Rights Reserved
+# Copyright 2019 QuantRocket - All Rights Reserved
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -20,6 +20,7 @@ from quantrocket.cli.utils.output import json_to_cli
 from quantrocket.cli.utils.stream import to_bytes
 from quantrocket.cli.utils.parse import dict_strs_to_dict, dict_to_dict_strs
 from quantrocket.cli.utils.files import write_response_to_filepath_or_buffer
+from quantrocket.utils.parse import _read_moonshot_or_pnl_csv
 
 def place_orders(orders=None, infilepath_or_buffer=None):
     """
@@ -47,7 +48,7 @@ def place_orders(orders=None, infilepath_or_buffer=None):
     --------
     >>> orders = []
     >>> order1 = {
-            'ConId':123456,
+            'Sid':'FIBBG123456',
             'Action':'BUY',
             'Exchange':'SMART',
             'TotalQuantity':100,
@@ -93,18 +94,18 @@ def _cli_place_orders(*args, **kwargs):
         kwargs["orders"] = orders
     return json_to_cli(place_orders, *args, **kwargs)
 
-def cancel_orders(order_ids=None, conids=None, order_refs=None, accounts=None,
+def cancel_orders(order_ids=None, sids=None, order_refs=None, accounts=None,
                   cancel_all=None):
     """
-    Cancel one or more orders by order ID, conid, or order ref.
+    Cancel one or more orders by order ID, sid, or order ref.
 
     Parameters
     ----------
     order_ids : list of str, optional
         cancel these order IDs
 
-    conids : list of int, optional
-        cancel orders for these conids
+    sids : list of str, optional
+        cancel orders for these sids
 
     order_refs: list of str, optional
         cancel orders for these order refs
@@ -126,9 +127,9 @@ def cancel_orders(order_ids=None, conids=None, order_refs=None, accounts=None,
 
     >>> cancel_orders(order_ids=['6002:45','6002:46'])
 
-    Cancel orders by conid:
+    Cancel orders by sid:
 
-    >>> cancel_orders(conids=[123456])
+    >>> cancel_orders(sids=["FIBBG123456"])
 
     Cancel orders by order ref:
 
@@ -141,8 +142,8 @@ def cancel_orders(order_ids=None, conids=None, order_refs=None, accounts=None,
     params = {}
     if order_ids:
         params["order_ids"] = order_ids
-    if conids:
-        params["conids"] = conids
+    if sids:
+        params["sids"] = sids
     if order_refs:
         params["order_refs"] = order_refs
     if accounts:
@@ -158,7 +159,7 @@ def _cli_cancel_orders(*args, **kwargs):
     return json_to_cli(cancel_orders, *args, **kwargs)
 
 def download_order_statuses(filepath_or_buffer=None, output="csv",
-                            order_ids=None, conids=None, order_refs=None,
+                            order_ids=None, sids=None, order_refs=None,
                             accounts=None, open_orders=None,
                             start_date=None, end_date=None, fields=None):
     """
@@ -175,8 +176,8 @@ def download_order_statuses(filepath_or_buffer=None, output="csv",
     order_ids : list of str, optional
         limit to these order IDs
 
-    conids : list of int, optional
-        limit to orders for these conids
+    sids : list of str, optional
+        limit to orders for these sids
 
     order_refs : list of str, optional
         limit to orders for these order refs
@@ -213,9 +214,9 @@ def download_order_statuses(filepath_or_buffer=None, output="csv",
 
     >>> download_order_statuses(open_orders=True, fields=["LmtPrice", "OcaGroup"])
 
-    Download order status of open orders by conid:
+    Download order status of open orders by sid:
 
-    >>> download_order_statuses(conids=[123456], open_orders=True)
+    >>> download_order_statuses(sids=["FIBBG123456"], open_orders=True)
 
     Download order status of open orders by order ref:
 
@@ -224,8 +225,8 @@ def download_order_statuses(filepath_or_buffer=None, output="csv",
     params = {}
     if order_ids:
         params["order_ids"] = order_ids
-    if conids:
-        params["conids"] = conids
+    if sids:
+        params["sids"] = sids
     if order_refs:
         params["order_refs"] = order_refs
     if accounts:
@@ -260,7 +261,7 @@ def _cli_download_order_statuses(*args, **kwargs):
     return json_to_cli(download_order_statuses, *args, **kwargs)
 
 def download_positions(filepath_or_buffer=None, output="csv",
-                       order_refs=None, accounts=None, conids=None,
+                       order_refs=None, accounts=None, sids=None,
                        view="blotter", diff=False):
     """
     Query current positions and write results to file.
@@ -269,13 +270,11 @@ def download_positions(filepath_or_buffer=None, output="csv",
 
     There are two ways to view positions: blotter view (default) and broker view.
 
-    The default "blotter view" returns positions by account, conid, and order ref. Positions
+    The default "blotter view" returns positions by account, sid, and order ref. Positions
     are tracked based on execution records saved to the blotter database.
 
-    "Broker view" (view='broker') returns positions by account and conid (but
-    not order ref) as reported directly by IB. Broker view is more authoritative but less
-    informative than blotter view. Broker view is typically used to verify the accuracy
-    of blotter view.
+    "Broker view" (view='broker') returns positions by account and sid (but
+    not order ref) as reported directly by the broker.
 
     Parameters
     ----------
@@ -291,12 +290,12 @@ def download_positions(filepath_or_buffer=None, output="csv",
     accounts : list of str, optional
         limit to these accounts
 
-    conids : list of int, optional
-        limit to these conids
+    sids : list of str, optional
+        limit to these sids
 
     view : str, optional
-        whether to return 'broker' view of positions (by account and conid) or
-        default 'blotter' view (by account, conid, and order ref). Choices are:
+        whether to return 'broker' view of positions (by account and sid) or
+        default 'blotter' view (by account, sid, and order ref). Choices are:
         blotter, broker
 
     diff : bool
@@ -316,8 +315,8 @@ def download_positions(filepath_or_buffer=None, output="csv",
         params["order_refs"] = order_refs
     if accounts:
         params["accounts"] = accounts
-    if conids:
-        params["conids"] = conids
+    if sids:
+        params["sids"] = sids
     if view:
         params["view"] = view
     if diff:
@@ -343,20 +342,18 @@ def download_positions(filepath_or_buffer=None, output="csv",
 def _cli_download_positions(*args, **kwargs):
     return json_to_cli(download_positions, *args, **kwargs)
 
-def list_positions(order_refs=None, accounts=None, conids=None,
+def list_positions(order_refs=None, accounts=None, sids=None,
                    view="blotter", diff=False):
     """
     Query current positions and return them as a Python list.
 
     There are two ways to view positions: blotter view (default) and broker view.
 
-    The default "blotter view" returns positions by account, conid, and order ref. Positions
+    The default "blotter view" returns positions by account, sid, and order ref. Positions
     are tracked based on execution records saved to the blotter database.
 
-    "Broker view" (view='broker') returns positions by account and conid (but
-    not order ref) as reported directly by IB. Broker view is more authoritative but less
-    informative than blotter view. Broker view is typically used to verify the accuracy
-    of blotter view.
+    "Broker view" (view='broker') returns positions by account and sid (but
+    not order ref) as reported directly by the broker.
 
     Parameters
     ----------
@@ -366,12 +363,12 @@ def list_positions(order_refs=None, accounts=None, conids=None,
     accounts : list of str, optional
         limit to these accounts
 
-    conids : list of int, optional
-        limit to these conids
+    sids : list of str, optional
+        limit to these sids
 
     view : str, optional
-        whether to return 'broker' view of positions (by account and conid) or
-        default 'blotter' view (by account, conid, and order ref). Choices are:
+        whether to return 'broker' view of positions (by account and sid) or
+        default 'blotter' view (by account, sid, and order ref). Choices are:
         blotter, broker
 
     diff : bool
@@ -392,7 +389,7 @@ def list_positions(order_refs=None, accounts=None, conids=None,
     """
     f = six.StringIO()
     download_positions(f, output="json",
-                       conids=conids, accounts=accounts,
+                       sids=sids, accounts=accounts,
                        order_refs=order_refs, view=view,
                        diff=diff)
 
@@ -402,7 +399,7 @@ def list_positions(order_refs=None, accounts=None, conids=None,
         return []
 
 def close_positions(filepath_or_buffer=None, output="csv",
-                    order_refs=None, accounts=None, conids=None,
+                    order_refs=None, accounts=None, sids=None,
                     params=None):
     """
     Generate orders to close positions.
@@ -424,8 +421,8 @@ def close_positions(filepath_or_buffer=None, output="csv",
     accounts : list of str, optional
         limit to these accounts
 
-    conids : list of int, optional
-        limit to these conids
+    sids : list of str, optional
+        limit to these sids
 
     params : dict of PARAM:VALUE, optional
         additional parameters to append to each row in output (pass as {param:value},
@@ -450,8 +447,8 @@ def close_positions(filepath_or_buffer=None, output="csv",
         _params["order_refs"] = order_refs
     if accounts:
         _params["accounts"] = accounts
-    if conids:
-        _params["conids"] = conids
+    if sids:
+        _params["sids"] = sids
     if params:
         _params["params"] = dict_to_dict_strs(params)
 
@@ -479,7 +476,7 @@ def _cli_close_positions(*args, **kwargs):
     return json_to_cli(close_positions, *args, **kwargs)
 
 def download_executions(filepath_or_buffer=None,
-                        order_refs=None, accounts=None, conids=None,
+                        order_refs=None, accounts=None, sids=None,
                         start_date=None, end_date=None):
     """
     Query executions from the executions database.
@@ -495,8 +492,8 @@ def download_executions(filepath_or_buffer=None,
     accounts : list of str, optional
         limit to these accounts
 
-    conids : list of int, optional
-        limit to these conids
+    sids : list of str, optional
+        limit to these sids
 
     start_date : str (YYYY-MM-DD), optional
         limit to executions on or after this date
@@ -513,8 +510,8 @@ def download_executions(filepath_or_buffer=None,
         params["order_refs"] = order_refs
     if accounts:
         params["accounts"] = accounts
-    if conids:
-        params["conids"] = conids
+    if sids:
+        params["sids"] = sids
     if start_date:
         params["start_date"] = start_date
     if end_date:
@@ -532,14 +529,14 @@ def _cli_download_executions(*args, **kwargs):
     return json_to_cli(download_executions, *args, **kwargs)
 
 def download_pnl(filepath_or_buffer=None,
-                 order_refs=None, accounts=None, conids=None,
-                 start_date=None, end_date=None, time=None,
+                 order_refs=None, accounts=None, sids=None,
+                 start_date=None, end_date=None, timezone=None,
                  details=False, output="csv"):
     """
     Query trading performance and return a CSV of results or PDF tearsheet.
 
     Trading performance is broken down by account and order ref and optionally by
-    conid.
+    sid.
 
     Parameters
     ----------
@@ -552,8 +549,8 @@ def download_pnl(filepath_or_buffer=None,
     accounts : list of str, optional
         limit to these accounts
 
-    conids : list of int, optional
-        limit to these conids
+    sids : list of str, optional
+        limit to these sids
 
     start_date : str (YYYY-MM-DD), optional
         limit to pnl on or after this date
@@ -561,15 +558,14 @@ def download_pnl(filepath_or_buffer=None,
     end_date : str (YYYY-MM-DD), optional
         limit to pnl on or before this date
 
-    time : str (HH:MM:SS [TZ]), optional
-        time of day (with optional timezone) for which to calculate daily PNL (default is
-        11:59:59 UTC)
-
     details : bool
         return detailed results for all securities instead of aggregating to
         account/order ref level (only supported for a single account and order ref
         at a time)
 
+    timezone : str, optional
+        return execution times in this timezone (default UTC)
+
     output : str, required
         the output format (choices are csv or pdf, default is csv)
 
@@ -582,16 +578,16 @@ def download_pnl(filepath_or_buffer=None,
         params["order_refs"] = order_refs
     if accounts:
         params["accounts"] = accounts
-    if conids:
-        params["conids"] = conids
+    if sids:
+        params["sids"] = sids
     if start_date:
         params["start_date"] = start_date
     if end_date:
         params["end_date"] = end_date
-    if time:
-        params["time"] = time
     if details:
         params["details"] = details
+    if timezone:
+        params["timezone"] = timezone
 
     output = output or "csv"
 
@@ -608,3 +604,28 @@ def download_pnl(filepath_or_buffer=None,
 
 def _cli_download_pnl(*args, **kwargs):
     return json_to_cli(download_pnl, *args, **kwargs)
+
+def read_pnl_csv(filepath_or_buffer):
+    """
+    Load a PNL CSV into a DataFrame.
+
+    This is a light wrapper around pd.read_csv that handles setting index
+    columns and casting to proper data types.
+
+    Parameters
+    ----------
+    filepath_or_buffer : string or file-like, required
+        path to CSV
+
+    Returns
+    -------
+    DataFrame
+        a multi-index (Field, Date[, Time]) DataFrame of backtest
+        results, with sids or strategy codes as columns
+
+    Examples
+    --------
+    >>> results = read_pnl_csv("pnl.csv")
+    >>> returns = results.loc["Return"]
+    """
+    return _read_moonshot_or_pnl_csv(filepath_or_buffer)
\ No newline at end of file
