@@ -60,11 +60,15 @@ Examples:
 
 Download application logs:
 
-    quantrocket flightlog get /path/to/localdir/app.log
+    quantrocket flightlog get app.log
 
 Download detailed logs:
 
-    quantrocket flightlog get --detail /path/to/localdir/system.log
+    quantrocket flightlog get --detail sys.log
+
+Download detailed logs for the history service:
+
+    quantrocket flightlog get --detail --match quantrocket_history sys.log
     """
     parser = _subparsers.add_parser(
         "get",
@@ -80,6 +84,10 @@ Download detailed logs:
         action="store_true",
         help="download detailed logs from logspout, otherwise download log messages from "
         "flightlog only")
+    parser.add_argument(
+        "-m", "--match",
+        metavar="PATTERN",
+        help="filter the logfile to lines containing this string")
     parser.set_defaults(func="quantrocket.flightlog._cli_download_logfile")
 
     examples = """
@@ -117,3 +125,60 @@ Log the output from another command:
         default="quantrocket.cli",
         help="the logger name")
     parser.set_defaults(func="quantrocket.flightlog._cli_log_message")
+
+    examples = """
+Set or show the flightlog timezone.
+
+Examples:
+
+Set the flightlog timezone to America/New_York:
+
+    quantrocket flightlog timezone America/New_York
+
+Show the current flightlog timezone:
+
+    quantrocket flightlog timezone
+    """
+    parser = _subparsers.add_parser(
+        "timezone",
+        help="set or show the flightlog timezone",
+        epilog=examples,
+        formatter_class=argparse.RawDescriptionHelpFormatter)
+    parser.add_argument(
+        "tz",
+        nargs="?",
+        metavar="TZ",
+        help="the timezone to set (pass a partial timezone string such as 'newyork' "
+        "or 'europe' to see close matches, or pass '?' to see all choices)")
+    parser.set_defaults(func="quantrocket.flightlog._cli_get_or_set_timezone")
+
+    examples = """
+Set or show the Papertrail log configuration.
+
+See http://qrok.it/h/pt to learn more.
+
+Examples:
+
+Set the Papertrail host and port to log to:
+
+    quantrocket flightlog papertrail --host logs.papertrailapp.com --port 55555
+
+Show the current papertrail config:
+
+    quantrocket flightlog papertrail
+    """
+    parser = _subparsers.add_parser(
+        "papertrail",
+        help="set or show the Papertrail log configuration",
+        epilog=examples,
+        formatter_class=argparse.RawDescriptionHelpFormatter)
+    parser.add_argument(
+        "--host",
+        metavar="HOST",
+        help="the Papertrail host to log to")
+    parser.add_argument(
+        "--port",
+        metavar="PORT",
+        type=int,
+        help="the Papertrail port to log to")
+    parser.set_defaults(func="quantrocket.flightlog._cli_get_or_set_papertrail_config")
