@@ -217,7 +217,8 @@ Delete a database called "usa-stk-trades":
     parser.set_defaults(func="quantrocket.realtime._cli_drop_db")
 
     examples = """
-Delete ticks from a tick database.
+Delete ticks from a tick database. Does not delete any aggregate
+database records.
 
 Deleting ticks is a way to free up disk space by deleting ticks older
 than a certain threshold while maintaining the ability to continue
@@ -229,25 +230,12 @@ deletes chunks in which *all* of the ticks are older than you specify. If
 some of the ticks are older but some are newer, the chunk is not deleted.
 This means you may still see older data returned in queries.
 
-Note: when using --cascade to also delete records from aggregate databases,
-the only aggregate records that will be deleted are ones corresponding to the
-ticks being deleted at the same time. This can have unintuitive consequences
-if you sometimes use --cascade and sometimes don't. For example, if you
-delete ticks older than 1 hour without --cascade, then repeat the function
-with --cascade, no aggregate records will be deleted. This is because the
-tick records older than 1 hour were already deleted previously and thus there
-can be no cascading delete of aggregate records on the subsequent call.
-
 Examples:
 
 Delete ticks older than 7 days in a database called 'usa-tech-stk-tick' (no
-aggregate records are deleted by default):
+aggregate records are deleted):
 
     quantrocket realtime drop-ticks usa-tech-stk-tick --older-than 7d
-
-Delete ticks older than 7 days, including the associated aggregate records:
-
-    quantrocket realtime drop-ticks usa-tech-stk-tick --older-than 7d --cascade
     """
     parser = _subparsers.add_parser(
         "drop-ticks",
@@ -263,12 +251,6 @@ Delete ticks older than 7 days, including the associated aggregate records:
         required=True,
         help="delete ticks older than this (use a Pandas timedelta string, for example "
         "7d)")
-    parser.add_argument(
-        "--cascade",
-        action="store_true",
-        help="also delete records that are older than older_than from this tick database's "
-       "aggregate database(s), if any. By default, does not delete any aggregate "
-       "database records.")
     parser.set_defaults(func="quantrocket.realtime._cli_drop_ticks")
 
     examples = """
