@@ -156,7 +156,8 @@ def collect_ibkr_listings(exchanges=None, sec_types=None, currencies=None,
     ----------
     exchanges : list or str
         one or more IBKR exchange codes to collect listings for (required
-        unless providing universes or sids)
+        unless providing universes or sids). For sample data use exchange
+        code 'FREE'
 
     sec_types : list of str, optional
         limit to these security types. Possible choices: STK, ETF, FUT, CASH, IND
@@ -180,6 +181,10 @@ def collect_ibkr_listings(exchanges=None, sec_types=None, currencies=None,
 
     Examples
     --------
+    Collect free sample listings:
+
+    >>> collect_ibkr_listings(exchanges="FREE")
+
     Collect all Toronto Stock Exchange stock listings:
 
     >>> collect_ibkr_listings(exchanges="TSE", sec_types="STK")
@@ -1071,7 +1076,7 @@ def _cli_in_status_since(status, since=None, in_=None, ago=None):
                                    freq=since, normalize=False)
 
     # For >1D freq, normalize to midnight
-    if required_since.freq.isAnchored() or required_since.freq.rule_code == "D":
+    if required_since.freq.is_anchored() or required_since.freq.rule_code == "D":
         required_since = pd.date_range(periods=5, end=dt, freq=since, normalize=True)
         required_since = required_since[-1]
     else:
@@ -1100,7 +1105,7 @@ def _cli_in_status_until(status, until=None, in_=None, ago=None):
                                    freq=until, normalize=False)
 
     # For >1D freq, normalize to midnight
-    if required_until.freq.isAnchored() or required_until.freq.rule_code == "D":
+    if required_until.freq.is_anchored() or required_until.freq.rule_code == "D":
         required_until = pd.date_range(start=dt, periods=5,
                                    freq=until, normalize=True)
         # due to normalize=True, the date range might include a time before the
