@@ -1,4 +1,4 @@
-# Copyright 2017 QuantRocket - All Rights Reserved
+# Copyright 2019 QuantRocket - All Rights Reserved
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -20,10 +20,11 @@ from quantrocket.houston import houston
 from quantrocket.cli.utils.output import json_to_cli
 from quantrocket.cli.utils.files import write_response_to_filepath_or_buffer
 from quantrocket.cli.utils.parse import dict_strs_to_dict, dict_to_dict_strs
-from quantrocket.exceptions import ParameterError
+from quantrocket.utils.parse import _read_moonshot_or_pnl_csv
 
 def backtest(strategies, start_date=None, end_date=None, segment=None, allocations=None,
-             nlv=None, params=None, details=None, output="csv", csv=None, filepath_or_buffer=None):
+             nlv=None, params=None, details=None, output="csv", filepath_or_buffer=None,
+             no_cache=False):
     """
     Backtest one or more strategies.
 
@@ -70,13 +71,14 @@ def backtest(strategies, start_date=None, end_date=None, segment=None, allocatio
     output : str, required
         the output format (choices are csv or pdf)
 
-    csv : bool
-       DEPRECATED: this argument will be removed in a future version. This argument
-       may be omitted as CSV is the default.
-
     filepath_or_buffer : str, optional
         the location to write the results file (omit to write to stdout)
 
+    no_cache : bool
+        don't use cached files even if available. Using cached files speeds
+        up backtests but may be undesirable if underlying data has changed.
+        See http://qrok.it/h/mcache to learn more about caching in Moonshot.
+
     Returns
     -------
     None
@@ -108,12 +110,6 @@ def backtest(strategies, start_date=None, end_date=None, segment=None, allocatio
     if output not in ("csv", "pdf"):
         raise ValueError("invalid output: {0} (choices are csv or pdf".format(output))
 
-    if csv is not None:
-        import warnings
-        warnings.warn(
-            "the `csv` argument is deprecated and will removed in a future version; "
-            "this argument may be omitted as csv is the default", DeprecationWarning)
-
     _params = {}
 
     if strategies:
@@ -132,6 +128,8 @@ def backtest(strategies, start_date=None, end_date=None, segment=None, allocatio
         _params["details"] = details
     if params:
         _params["params"] = dict_to_dict_strs(params)
+    if no_cache:
+        _params["no_cache"] = no_cache
 
     response = houston.post("/moonshot/backtests.{0}".format(output),
                             params=_params, timeout=60*60*24)
@@ -157,6 +155,9 @@ def read_moonshot_csv(filepath_or_buffer):
     """
     Load a Moonshot backtest CSV into a DataFrame.
 
+    This is a light wrapper around pd.read_csv that handles setting index
+    columns and casting to proper data types.
+
     Parameters
     ----------
     filepath_or_buffer : string or file-like, required
@@ -166,105 +167,19 @@ def read_moonshot_csv(filepath_or_buffer):
     -------
     DataFrame
         a multi-index (Field, Date[, Time]) DataFrame of backtest
-        results, with conids or strategy codes as columns
+        results, with sids or strategy codes as columns
 
     Examples
     --------
     >>> results = read_moonshot_csv("moonshot_backtest.csv")
     >>> returns = results.loc["Return"]
     """
-    try:
-        import pandas as pd
-    except ImportError:
-        raise ImportError("pandas must be installed to use this function")
-
-    results = pd.read_csv(filepath_or_buffer, parse_dates=["Date"])
-    index_cols = ["Field", "Date"]
-    if "Time" in results.columns:
-        index_cols.append("Time")
-    results = results.set_index(index_cols)
-
-    fields_in_results = results.index.get_level_values("Field").unique()
-
-    # Cast to float
-    float_fields = [
-        "Return",
-        "Signal",
-        "Weight",
-        "NetExposure",
-        "Turnover",
-        "Commission",
-        "Slippage",
-        "Benchmark",
-        "AbsWeight",
-        "AbsExposure",
-        "TotalHoldings",
-
-    ]
-    for field in float_fields:
-        if field in fields_in_results:
-            results.loc[[field]] = results.loc[[field]].astype(pd.np.float64)
-
-    return results
-
-def intraday_to_daily(results):
-    """
-    Roll up a DataFrame of intraday performance results to daily, dropping
-    the "Time" level from the multi-index.
-
-    Parameters
-    ----------
-    results : DataFrame, required
-         a DataFrame of intraday Moonshot backtest results, with a "Time" level
-         in the index
-
-    Returns
-    -------
-    DataFrame
-        a DataFrame of daily Moonshot backtest results, without a "Time" level in
-        the index
-
-    Examples
-    --------
-    >>> intraday_results = read_moonshot_csv("moonshot_intraday_backtest.csv")
-    >>> daily_results = intraday_to_daily(intraday_results)
-    """
-    try:
-        import pandas as pd
-    except ImportError:
-        raise ImportError("pandas must be installed to use this function")
-
-    if "Time" not in results.index.names:
-        raise ParameterError("results DataFrame must have 'Time' level in index")
-
-    fields_in_results = results.index.get_level_values("Field").unique()
-
-    daily_results = {}
-
-    # how to aggregate by field
-    aggregation_methods = {
-        "sum": ["Return", "Turnover", "Commission", "Slippage"],
-        "max": ["AbsExposure", "TotalHoldings", "AbsWeight"],
-        "mean": ["NetExposure", "Weight"],
-        "last": ["Benchmark"],
-    }
-
-    for aggregation_method, fields_to_aggregate in aggregation_methods.items():
-        for field in fields_to_aggregate:
-            if field not in fields_in_results:
-                continue
-
-            field_results = results.loc[field].astype(pd.np.float64)
-            grouped = field_results.groupby(field_results.index.get_level_values("Date"))
-            daily_results[field] = getattr(grouped, aggregation_method)()
-
-    daily_results = pd.concat(daily_results, names=["Field","Date"])
-    return daily_results
+    return _read_moonshot_or_pnl_csv(filepath_or_buffer)
 
 def scan_parameters(strategies, start_date=None, end_date=None, segment=None,
                     param1=None, vals1=None, param2=None, vals2=None,
                     allocations=None, nlv=None, params=None, output="csv",
-                    csv=None, filepath_or_buffer=None):
+                    filepath_or_buffer=None, no_cache=False):
     """
     Run a parameter scan for one or more strategies.
 
@@ -318,13 +233,14 @@ def scan_parameters(strategies, start_date=None, end_date=None, segment=None,
     output : str, required
         the output format (choices are csv or pdf)
 
-    csv : bool
-        DEPRECATED: this argument will be removed in a future version. This argument
-        may be omitted as CSV is the default.
-
     filepath_or_buffer : str, optional
         the location to write the results file (omit to write to stdout)
 
+    no_cache : bool
+        don't use cached files even if available. Using cached files speeds
+        up backtests but may be undesirable if underlying data has changed.
+        See http://qrok.it/h/mcache to learn more about caching in Moonshot.
+
     Returns
     -------
     None
@@ -363,12 +279,6 @@ def scan_parameters(strategies, start_date=None, end_date=None, segment=None,
     if output not in ("csv", "pdf"):
         raise ValueError("invalid output: {0} (choices are csv or pdf".format(output))
 
-    if csv is not None:
-        import warnings
-        warnings.warn(
-            "the `csv` argument is deprecated and will removed in a future version; "
-            "this argument may be omitted as csv is the default", DeprecationWarning)
-
     _params = {}
     if strategies:
         _params["strategies"] = strategies
@@ -392,6 +302,8 @@ def scan_parameters(strategies, start_date=None, end_date=None, segment=None,
         _params["nlv"] = dict_to_dict_strs(nlv)
     if params:
         _params["params"] = dict_to_dict_strs(params)
+    if no_cache:
+        _params["no_cache"] = no_cache
 
     response = houston.post("/moonshot/paramscans.{0}".format(output), params=_params, timeout=60*60*24)
 
@@ -415,21 +327,22 @@ def _cli_scan_parameters(*args, **kwargs):
 def ml_walkforward(strategy, start_date, end_date, train, min_train=None, rolling_train=None,
                    model_filepath=None, force_nonincremental=None, segment=None,
                    allocation=None, nlv=None, params=None,
-                   details=None, progress=False, filepath_or_buffer=None):
+                   details=None, progress=False, filepath_or_buffer=None,
+                   no_cache=False):
     """
-    Run a walk-forward backtest of a machine learning strategy.
+    Run a walk-forward optimization of a machine learning strategy.
 
-    The date range will be split into segments of `--train` size. For each
+    The date range will be split into segments of `train` size. For each
     segment, the model will be trained with the data, then the trained model will
     be backtested on the following segment.
 
     By default, uses scikit-learn's StandardScaler+SGDRegressor. Also supports other
     scikit-learn models/pipelines and Keras models. To customize model, instantiate
-    the model locally, serialize it to disk, and pass the filename of the serialized
-    model as `--model`.
+    the model locally, serialize it to disk, and pass the path of the serialized
+    model as `model_filepath`.
 
-    Supports expanding walk-forward backtests (the default), which use an anchored start date
-    for model training, or rolling walk-forward backtests (by specifying `--rolling-train`),
+    Supports expanding walk-forward optimizations (the default), which use an anchored start date
+    for model training, or rolling walk-forward optimizations (by specifying `rolling_train`),
     which use a rolling or non-anchored start date for model training.
 
     Returns a backtest results CSV and a dump of the machine learning model
@@ -442,7 +355,7 @@ def ml_walkforward(strategy, start_date, end_date, train, min_train=None, rollin
 
     start_date : str (YYYY-MM-DD), required
         the analysis start date (note that model training will start on this date
-        but backtest will not start until after the initial training period)
+        but backtesting will not start until after the initial training period)
 
     end_date : str (YYYY-MM-DD), required
         the analysis end date
@@ -468,7 +381,7 @@ def ml_walkforward(strategy, start_date, end_date, train, min_train=None, rollin
     force_nonincremental : bool, optional
         force the model to be trained non-incrementally (i.e. load entire training
         data set into memory) even if it supports incremental learning. Must be True
-        in order to perform a rolling (as opposed to expanding) walk-forward backtest
+        in order to perform a rolling (as opposed to expanding) walk-forward optimization
         with a model that supports incremental learning. Default False.
 
     segment : str, optional
@@ -500,13 +413,18 @@ def ml_walkforward(strategy, start_date, end_date, train, min_train=None, rollin
         pattern to use for extracting the zipped files. For example, if the path is
         my_ml*, files will extracted to my_ml_results.csv and my_ml_trained_model.joblib.
 
+    no_cache : bool
+        don't use cached files even if available. Using cached files speeds
+        up backtests but may be undesirable if underlying data has changed.
+        See http://qrok.it/h/mcache to learn more about caching in Moonshot.
+
     Returns
     -------
     None
 
     Examples
     --------
-    Run a walk-forward backtest using the default model and retrain the model
+    Run a walk-forward optimization using the default model and retrain the model
     annually, writing the backtest results and trained model to demo_ml_results.csv
     and demo_ml_trained_model.joblib, respectively:
 
@@ -532,7 +450,7 @@ def ml_walkforward(strategy, start_date, end_date, train, min_train=None, rollin
             model_filepath="my_model.joblib",
             filepath_or_buffer="demo_ml*")
 
-    Run a walk-forward backtest using a custom model (serialized with joblib),
+    Run a walk-forward optimization using a custom model (serialized with joblib),
     retrain the model annually, don't perform backtesting until after 5 years
     of initial training, and further split the training and backtesting into
     quarterly segments to reduce memory usage:
@@ -591,6 +509,8 @@ def ml_walkforward(strategy, start_date, end_date, train, min_train=None, rollin
         _params["progress"] = progress
     if params:
         _params["params"] = dict_to_dict_strs(params)
+    if no_cache:
+        _params["no_cache"] = no_cache
 
     url = "/moonshot/ml/walkforward/{0}.zip".format(strategy)
 
