@@ -17,7 +17,7 @@
 import unittest
 import os
 import pandas as pd
-from quantrocket.moonshot import read_moonshot_csv, intraday_to_daily
+from quantrocket.moonshot import read_moonshot_csv
 
 EOD_AGGREGATE_RESULTS = {
     'dma-tech': {
@@ -39,7 +39,7 @@ EOD_AGGREGATE_RESULTS = {
         ('Turnover', '2016-03-18'): 0.0}}
 
 EOD_DETAILED_RESULTS = {
-    'AAPL(265598)': {
+    'AAPL(FI265598)': {
         ('AbsExposure', '2016-03-17'): 0.0,
         ('AbsExposure', '2016-03-18'): 0.0,
         ('AbsWeight', '2016-03-17'): 0.0,
@@ -62,7 +62,7 @@ EOD_DETAILED_RESULTS = {
         ('Turnover', '2016-03-18'): 0.0,
         ('Weight', '2016-03-17'): 0.0,
         ('Weight', '2016-03-18'): 0.0},
-    'AMZN(3691937)': {
+    'AMZN(FI3691937)': {
         ('AbsExposure', '2016-03-17'): 0.3333333333333333,
         ('AbsExposure', '2016-03-18'): 0.3333333333333333,
         ('AbsWeight', '2016-03-17'): 0.3333333333333333,
@@ -146,7 +146,7 @@ INTRADAY_AGGREGATE_RESULTS = {
 }
 
 INTRADAY_DETAILED_RESULTS = {
-    'EUR.USD(12087792)': {
+    'EUR.USD(FXEURUSD)': {
         ('AbsExposure', '2018-12-18', '09:00:00'): 0.0,
         ('AbsExposure', '2018-12-18', '10:00:00'): 0.0,
         ('AbsExposure', '2018-12-18', '11:00:00'): 0.0,
@@ -219,7 +219,7 @@ INTRADAY_DETAILED_RESULTS = {
         ('Weight', '2018-12-19', '09:00:00'): 0.1,
         ('Weight', '2018-12-19', '10:00:00'): 0.15,
         ('Weight', '2018-12-19', '11:00:00'): 0.2},
-    'GBP.USD(12087797)': {
+    'GBP.USD(FXGBPUSD)': {
         ('AbsExposure', '2018-12-18', '09:00:00'): 0.0,
         ('AbsExposure', '2018-12-18', '10:00:00'): 0.0,
         ('AbsExposure', '2018-12-18', '11:00:00'): 0.0,
@@ -373,138 +373,3 @@ class ReadMoonshotCsvTestCase(unittest.TestCase):
             INTRADAY_DETAILED_RESULTS
         )
 
-class IntradayToDailyTestCase(unittest.TestCase):
-    """
-    Test cases for `quantrocket.moonshot.intraday_to_daily`.
-    """
-
-    def tearDown(self):
-        if os.path.exists("results.csv"):
-            os.remove("results.csv")
-
-
-    def test_aggregate_intraday_to_daily(self):
-
-        results = pd.DataFrame.from_dict(INTRADAY_AGGREGATE_RESULTS)
-        results.index.set_names(["Field","Date", "Time"], inplace=True)
-        results.to_csv("results.csv")
-
-        intraday_results = read_moonshot_csv("results.csv")
-
-        daily_results = intraday_to_daily(intraday_results)
-
-        daily_results = daily_results.reset_index()
-        daily_results.loc[:, "Date"] = daily_results.Date.dt.strftime("%Y-%m-%d")
-        daily_results = daily_results.set_index(["Field", "Date"])
-
-        self.assertDictEqual(
-            daily_results.to_dict(),
-            {'fx-revert': {
-                # max
-                ('AbsExposure', '2018-12-18'): 0.0,
-                ('AbsExposure', '2018-12-19'): 1.0,
-                # max
-                ('AbsWeight', '2018-12-18'): 0.0,
-                ('AbsWeight', '2018-12-19'): 1.0,
-                # last
-                ('Benchmark', '2018-12-18'): 1.13606,
-                ('Benchmark', '2018-12-19'): 1.142185,
-                # sum
-                ('Commission', '2018-12-18'): 0.00022,
-                ('Commission', '2018-12-19'): 0.0001,
-                # mean
-                ('NetExposure', '2018-12-18'): 0.0,
-                ('NetExposure', '2018-12-19'): 1.5,
-                # sum
-                ('Return', '2018-12-18'): 0.0,
-                ('Return', '2018-12-19'): 0.0005820400950750315,
-                # sum
-                ('Slippage', '2018-12-18'): 4e-05,
-                ('Slippage', '2018-12-19'): 5.000000000000001e-05,
-                # max
-                ('TotalHoldings', '2018-12-18'): 0.0,
-                ('TotalHoldings', '2018-12-19'): 5.0,
-                # sum
-                ('Turnover', '2018-12-18'): 0.1,
-                ('Turnover', '2018-12-19'): 0.30000000000000004}}
-        )
-
-    def test_detailed_intraday_to_daily(self):
-
-        results = pd.DataFrame.from_dict(INTRADAY_DETAILED_RESULTS)
-        results.index.set_names(["Field","Date", "Time"], inplace=True)
-        results.to_csv("results.csv")
-
-        intraday_results = read_moonshot_csv("results.csv")
-
-        daily_results = intraday_to_daily(intraday_results)
-
-        daily_results = daily_results.reset_index()
-        daily_results.loc[:, "Date"] = daily_results.Date.dt.strftime("%Y-%m-%d")
-        daily_results = daily_results.set_index(["Field", "Date"])
-
-        daily_results = daily_results.where(daily_results.notnull(), None)
-
-        self.assertDictEqual(
-            daily_results.to_dict(),
-            {'EUR.USD(12087792)': { # max
-                                   ('AbsExposure', '2018-12-18'): 0.0,
-                                   ('AbsExposure', '2018-12-19'): 0.2,
-                                   # max
-                                   ('AbsWeight', '2018-12-18'): 0.0,
-                                   ('AbsWeight', '2018-12-19'): 0.2,
-                                   # last
-                                   ('Benchmark', '2018-12-18'): 1.13606,
-                                   ('Benchmark', '2018-12-19'): 1.142185,
-                                   # sum
-                                   ('Commission', '2018-12-18'): 1e-05,
-                                   ('Commission', '2018-12-19'): 2e-05,
-                                   # mean
-                                   ('NetExposure', '2018-12-18'): 0.0,
-                                   ('NetExposure', '2018-12-19'): 0.20000000000000004,
-                                   # sum
-                                   ('Return', '2018-12-18'): 0.0,
-                                   ('Return', '2018-12-19'): 0.00035730412741801225,
-                                   # sum
-                                   ('Slippage', '2018-12-18'): 0.0,
-                                   ('Slippage', '2018-12-19'): 4e-05,
-                                   # max
-                                   ('TotalHoldings', '2018-12-18'): 0.0,
-                                   ('TotalHoldings', '2018-12-19'): 2.0,
-                                   # sum
-                                   ('Turnover', '2018-12-18'): 0.0,
-                                   ('Turnover', '2018-12-19'): 0.30000000000000004,
-                                   # mean
-                                   ('Weight', '2018-12-18'): 0.0,
-                                   ('Weight', '2018-12-19'): 0.15},
-             'GBP.USD(12087797)': {# max
-                                   ('AbsExposure', '2018-12-18'): 0.0,
-                                   ('AbsExposure', '2018-12-19'): 0.2,
-                                   # max
-                                   ('AbsWeight', '2018-12-18'): 0.0,
-                                   ('AbsWeight', '2018-12-19'): 0.2,
-                                   # last
-                                   ('Benchmark', '2018-12-18'): None,
-                                   ('Benchmark', '2018-12-19'): None,
-                                   # sum
-                                   ('Commission', '2018-12-18'): 0.0,
-                                   ('Commission', '2018-12-19'): 3.0000000000000004e-05,
-                                   # mean
-                                   ('NetExposure', '2018-12-18'): 0.0,
-                                   ('NetExposure', '2018-12-19'): 0.20000000000000004,
-                                   # sum
-                                   ('Return', '2018-12-18'): 0.0,
-                                   ('Return', '2018-12-19'): 0.0007114899464124138,
-                                   # sum
-                                   ('Slippage', '2018-12-18'): 0.0,
-                                   ('Slippage', '2018-12-19'): 3.0000000000000004e-05,
-                                   # max
-                                   ('TotalHoldings', '2018-12-18'): 0.0,
-                                   ('TotalHoldings', '2018-12-19'): 1.0,
-                                   # sum
-                                   ('Turnover', '2018-12-18'): 0.0,
-                                   ('Turnover', '2018-12-19'): 0.0,
-                                   # mean
-                                   ('Weight', '2018-12-18'): 0.0,
-                                   ('Weight', '2018-12-19'): 0.20000000000000004}}
-        )
